@@ -245,7 +245,7 @@ func (reader *Reader) consumeLinesFromStream(stream io.Reader) {
 
 	reader.endsWithNewline = inspectionReader.endedWithNewline
 
-	log.Debug("Stream read in ", time.Since(t0))
+	log.Info("Stream read in ", time.Since(t0))
 }
 
 func (reader *Reader) tailFile() error {
@@ -333,8 +333,12 @@ func (reader *Reader) tailFile() error {
 //
 // Note that you must call reader.SetStyleForHighlighting() after this to get
 // highlighting.
-func NewReaderFromStream(name string, reader io.Reader, formatter chroma.Formatter, options ReaderOptions) *Reader {
-	mReader := newReaderFromStream(reader, nil, formatter, options)
+func NewReaderFromStream(name string, reader io.Reader, formatter chroma.Formatter, options ReaderOptions) (*Reader, error) {
+	zReader, err := ZReader(reader)
+	if err != nil {
+		return nil, err
+	}
+	mReader := newReaderFromStream(zReader, nil, formatter, options)
 
 	if len(name) > 0 {
 		mReader.Lock()
@@ -350,7 +354,7 @@ func NewReaderFromStream(name string, reader io.Reader, formatter chroma.Formatt
 		mReader.SetStyleForHighlighting(*options.Style)
 	}
 
-	return mReader
+	return mReader, nil
 }
 
 // newReaderFromStream creates a new stream reader
@@ -362,6 +366,9 @@ func NewReaderFromStream(name string, reader io.Reader, formatter chroma.Formatt
 //
 // If lexer is set, the file will be highlighted after being fully read.
 //
+// Whatever data we get from the reader, that's what we'll have. Or in other
+// words, if the input needs to be decompressed, do that before coming here.
+//
 // Note that you must call reader.SetStyleForHighlighting() after this to get
 // highlighting.
 func newReaderFromStream(reader io.Reader, originalFileName *string, formatter chroma.Formatter, options ReaderOptions) *Reader {
@@ -528,7 +535,7 @@ func NewReaderFromFilename(filename string, formatter chroma.Formatter, options
 		options.Lexer = lexers.Match(highlightingFilename)
 	}
 
-	returnMe := newReaderFromStream(stream, &filename, formatter, options)
+	returnMe := newReaderFromStream(stream, &highlightingFilename, formatter, options)
 
 	if options.Lexer == nil {
 		returnMe.highlightingDone.Store(true)
@@ -592,7 +599,7 @@ func highlightFromMemory(reader *Reader, formatter chroma.Formatter, options Rea
 		byteCount += int64(len(line.raw))
 
 		if byteCount > MAX_HIGHLIGHT_SIZE {
-			log.Debug("File too large for highlighting: ", byteCount)
+			log.Info("File too large for highlighting: ", byteCount)
 			reader.Unlock()
 			return
 		}
@@ -602,7 +609,7 @@ func highlightFromMemory(reader *Reader, formatter chroma.Formatter, options Rea
 	text := textAsString(reader, options.ShouldFormat)
 
 	if options.Lexer == nil && json.Valid([]byte(text)) {
-		log.Debug("Buffer is valid JSON, highlighting as JSON")
+		log.Info("Buffer is valid JSON, highlighting as JSON")
 		options.Lexer = lexers.Get("json")
 	}
 
